==> dwf-deploy-2.0.3.tgz: package/lib/dwf/repository.js <==
'use strict';

const coLoggerLib = require('../logger.js');

const coRequestLib = require('./request.js');
const Result = require('./result.js').Result;
const coValidateLib = require('./validate.js');
const coDwfAbstract = require('./abstract.js');

function Repository(ioCredential, ioOption) {
  this.loCredential = coValidateLib(ioCredential, 'object');
  this.loOption = coValidateLib(ioOption, 'object');
}

Repository.prototype.get_afTask2Update = function(isExt, iaoResultItem, ioProviderExt) {
  let lafTask = []; // note - waterfall stile tasks

  let loServiceProvider = {
    'ORG': ioProviderExt.org,
    'ORG_GUID': ioProviderExt.org_guid, // TODO - SP02 - will be provided by the deploy-service and has to fix the mta_provider.yaml
    'SPACE': ioProviderExt.space,
    'SPACE_GUID': ioProviderExt.space_guid, // TODO - SP02 - will be provided by the deploy-service and has to fix the mta_provider.yaml
    'ID': ioProviderExt.name
  };
  let loObjectType = {
    "ID" : ioProviderExt.extention,
    "URL_ROUTE" : ioProviderExt.route,
    'PROVIDER_ID': loServiceProvider.ID,
    'PROVIDER_ORG': loServiceProvider.ORG,
    'PROVIDER_ORG_GUID': loServiceProvider.ORG_GUID,
    'PROVIDER_SPACE': loServiceProvider.SPACE,
    'PROVIDER_SPACE_GUID': loServiceProvider.SPACE_GUID
  };
  let laoObjectInstance = [];
  iaoResultItem.forEach(function(ioResultItem) {
    let loObjectInstance = {
      'NAMESPACE': ioResultItem[Result.csKey_AOI_sNamespace],
      'ID': ioResultItem[Result.csKey_AOI_nID],
      'TYPE_ID': loObjectType.ID,
      'DESIGN_TIME_FILE_PATH': ioResultItem[Result.csKey_AOI_sFile]
    };
    laoObjectInstance.push(loObjectInstance);
  });

  let loRepository = this.loCredential[coDwfAbstract.cs_Credential_Key_Repository_v1];
  let loData = {
    uri: undefined, // note - update me on each step
    json: true,
    method: undefined, // note - update me on each step
    auth: {
      user: this.loCredential.user,
      pass: this.loCredential.password,
      sendImmediately: true
    },
    body: undefined // note - update me on each step
  };
  let lfCb2Reuse = function(isExt, ioData, ifCb) {
    return function(ioError, ioResponse, ioBody) {
      let lsExt = isExt;
      let loData = ioData;
      let lfCb = ifCb;
      let loError;
      if (typeof ioError !== 'undefined' && ioError !== null) {
        loError = ioError;
      } else if (ioResponse.statusCode !== 200) {
        loError = new Error('Failed, because ' + loData.method + ' on ' + loData.uri + ' returned ' + ioResponse.statusCode +
                            ' as a response status code with body ' + JSON.stringify(ioBody));
      }
      if (typeof loError === 'undefined' || loError === null) {
        coLoggerLib.log(' * ' + lsExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ok' + '(' + ioResponse.statusCode + ')');
      }
      lfCb(loError, loData.body);
    };
  };

  // Service Providers - GET
  lafTask.push(function(ifCb) {
    loData.uri = loRepository.url + '/' + 'providers';
    loData.method = 'GET';
    loData.body = undefined;

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });
  // Service Providers - POST - no checks are required, because of the upsert in the backend
  lafTask.push(function(iaoProviderGet, ifCb) {
    loData.uri = loRepository.url + '/' + 'providers';
    loData.method = 'POST';
    loData.body = [loServiceProvider];

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });
  // Object Types - GET
  lafTask.push(function(iaoProviderPost, ifCb) {
    loData.uri = loRepository.url + '/' + 'objectTypes';
    loData.method = 'GET';
    loData.body = undefined;

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });
  // Object Types - POST
  lafTask.push(function(iaoProviderPost, ifCb) {
    loData.uri = loRepository.url + '/' + 'objectTypes';
    loData.method = 'POST';
    loData.body = [loObjectType];

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });
  // Object Types - GET
  lafTask.push(function(iaoProviderPost, ifCb) {
    loData.uri = loRepository.url + '/' + 'objects';
    loData.method = 'GET';
    loData.body = undefined;

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });
  // Object Types - POST
  lafTask.push(function(iaoProviderPost, ifCb) {
    loData.uri = loRepository.url + '/' + 'objects';
    loData.method = 'POST';
    loData.body = laoObjectInstance;

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    if (loData.body.length > 0) { // Check - do not post with empty array
      let lfCb = lfCb2Reuse(isExt, loData, ifCb);
      coRequestLib(loData, lfCb);
    } else {
      coLoggerLib.log(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... skiped' + '(body = ' + JSON.stringify(loData.body) + ')');
      ifCb();
    }
  });

  return lafTask;
};

module.exports.Repository = Repository;

==> dwf-deploy-2.2.0.tgz: package/lib/dwf/repository.js <==
'use strict';

const coLoggerLib = require('../logger.js');

const coRequestLib = require('./request.js');
const Result = require('./result.js').Result;
const coValidateLib = require('./validate.js');
const coDwfAbstract = require('./abstract.js');

function Repository(ioCredential, ioOption) {
  this.loCredential = coValidateLib(ioCredential, 'object');
  this.loOption = coValidateLib(ioOption, 'object');
}
const lfCb2Reuse = function(isExt, ioData, ifCb) {
    return function(ioError, ioResponse, ioBody) {
      let lsExt = isExt;
      let loData = ioData;
      let lfCb = ifCb;
      let loError;
      if (typeof ioError !== 'undefined' && ioError !== null) {
        loError = ioError;
      } else if (ioResponse.statusCode !== 200) {
        loError = new Error('Failed, because ' + loData.method + ' on ' + loData.uri + ' returned ' + ioResponse.statusCode +
                            ' as a response status code with body ' + JSON.stringify(ioBody));
      }
      if (typeof loError === 'undefined' || loError === null) {
        coLoggerLib.log(' * ' + lsExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ok' + '(' + ioResponse.statusCode + ')');
      }
      lfCb(loError, ioResponse);
    };
  };
Repository.prototype.get_afTask2Get = function(isExt) {
  let lafTask = []; // note - waterfall stile tasks
  let loRepository = this.loCredential[coDwfAbstract.cs_Credential_Key_Repository_v1];
  let loData = {
    uri: undefined, // note - update me on each step
    json: true,
    method: undefined, // note - update me on each step
    auth: {
      user: this.loCredential.user,
      pass: this.loCredential.password,
      sendImmediately: true
    },
    body: undefined // note - update me on each step
  };

  // Object Types - GET
  lafTask.push(function(ifCb) {
    loData.uri = loRepository.url + '/' + 'objects';
    loData.method = 'GET';
    loData.body = undefined;

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });
  return lafTask;
};

Repository.prototype.get_afTask2Update = function(isExt, iaoResultItem, ioProviderExt) {
  let lafTask = []; // note - waterfall stile tasks

  let loServiceProvider = {
    'ORG': ioProviderExt.org,
    'ORG_GUID': ioProviderExt.org_guid, // TODO - SP02 - will be provided by the deploy-service and has to fix the mta_provider.yaml
    'SPACE': ioProviderExt.space,
    'SPACE_GUID': ioProviderExt.space_guid, // TODO - SP02 - will be provided by the deploy-service and has to fix the mta_provider.yaml
    'ID': ioProviderExt.name
  };
  let loObjectType = {
    "ID" : ioProviderExt.extention,
    "URL_ROUTE" : ioProviderExt.route,
    'PROVIDER_ID': loServiceProvider.ID,
    'PROVIDER_ORG': loServiceProvider.ORG,
    'PROVIDER_ORG_GUID': loServiceProvider.ORG_GUID,
    'PROVIDER_SPACE': loServiceProvider.SPACE,
    'PROVIDER_SPACE_GUID': loServiceProvider.SPACE_GUID
  };
  let laoObjectInstanceToUpdate = [];
  let laoObjectInstanceToDelete = [];
  let tableColumns = (Result.coExtentions.hasOwnProperty(isExt)) ? Result.coExtentions[isExt] : {};
  iaoResultItem.forEach(function(ioResultItem) {
    let loObjectInstance = {};
    Object.keys(tableColumns).forEach(function (key) {
    loObjectInstance[key] = ioResultItem[tableColumns[key]];
    });
    if(ioResultItem[Result.csKey_AOI_Action] === Result.ACTIONS.POST) {
        laoObjectInstanceToUpdate.push(loObjectInstance);
    } else if(ioResultItem[Result.csKey_AOI_Action] === Result.ACTIONS.DELETE) {
        laoObjectInstanceToDelete.push(loObjectInstance);
    }
  });

  let loRepository = this.loCredential[coDwfAbstract.cs_Credential_Key_Repository_v1];
  let loData = {
    uri: undefined, // note - update me on each step
    json: true,
    method: undefined, // note - update me on each step
    auth: {
      user: this.loCredential.user,
      pass: this.loCredential.password,
      sendImmediately: true
    },
    body: undefined // note - update me on each step
  };
/*
  // Service Providers - GET
  lafTask.push(function(ifCb) {
    loData.uri = loRepository.url + '/' + 'providers';
    loData.method = 'GET';
    loData.body = undefined;

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });
  */
  // Service Providers - POST - no checks are required, because of the upsert in the backend
  lafTask.push(function(ifCb) {
    loData.uri = loRepository.url + '/' + 'providers';
    loData.method = 'POST';
    loData.body = [loServiceProvider];

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });
  /*
  // Object Types - GET
  lafTask.push(function(iaoProviderPost, ifCb) {
    loData.uri = loRepository.url + '/' + 'objectTypes';
    loData.method = 'GET';
    loData.body = undefined;

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });
  */
  // Object Types - POST
  lafTask.push(function(iaoProviderPost, ifCb) {
    loData.uri = loRepository.url + '/' + 'objectTypes';
    loData.method = 'POST';
    loData.body = [loObjectType];

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    let lfCb = lfCb2Reuse(isExt, loData, ifCb);
    coRequestLib(loData, lfCb);
  });

  // Object Types - POST
  lafTask.push(function(iaoProviderPost, ifCb) {
    loData.uri = loRepository.url + '/' + 'objects';
    loData.method = 'POST';
    loData.body = laoObjectInstanceToUpdate;

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    if (loData.body.length > 0) { // Check - do not post with empty array
      let lfCb = lfCb2Reuse(isExt, loData, ifCb);
      coRequestLib(loData, lfCb);
    } else {
      coLoggerLib.log(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... skiped' + '(body = ' + JSON.stringify(loData.body) + ')');
      ifCb(null, null);
    }
  });
  // Deleting deployed files which are not in current repo
   lafTask.push(function(iaoProviderPost, ifCb) {
    loData.uri = loRepository.url + '/' + 'objects';
    loData.method = 'DELETE';
    loData.body = laoObjectInstanceToDelete;

    coLoggerLib.trace(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ');
    if (loData.body.length > 0) { // Check - do not post with empty array
      let lfCb = lfCb2Reuse(isExt, loData, ifCb);
      coRequestLib(loData, lfCb);
    } else {
      coLoggerLib.log(' * ' + isExt + ' - ' + loData.uri + ' ' + loData.method + ' ... skiped' + '(body = ' + JSON.stringify(loData.body) + ')');
      ifCb();
    }
  });

  return lafTask;
};

module.exports = {
  Repository,
  lfCb2Reuse
};
